# PyPetaKit5D

## Installation

This package is currently only available for Linux and has been tested with Python 3.11 but other versions may also work

The installation may take a long time
````
pip install --no-binary :all: --no-cache-dir PyPetaKit5D
````

## Uninstallation

It is recommended to use -v as it makes the uninstall much faster for this package
````
pip uninstall PyPetaKit5D -v
````

## Usage

Please refer to the [examples.ipynb](https://github.com/abcucberkeley/PyPetaKit5D/blob/main/examples.ipynb) notebook for step-by-step usage examples using our demo dataset. For a more detailed explanation of all the input variables, you can refer to our GUI's [wiki](https://github.com/abcucberkeley/PetaKit5D-GUI/wiki)

## Reference

Please cite our software if you find it useful in your work:

Xiongtao Ruan, Matthew Mueller, Gaoxiang Liu, Frederik Görlitz, Tian-Ming Fu, Daniel E. Milkie, Joshua L. Lillvis, Alexander Kuhn, Chu Yi Aaron Herr, Wilmene Hercule, Marc Nienhaus, Alison N. Killilea, Eric Betzig, Srigokul Upadhyayula. Image processing tools for petabyte-scale light sheet microscopy data. bioRxiv 2023.12.31.573734; doi: https://doi.org/10.1101/2023.12.31.573734
